#ifndef neo_AbstractFramework_hh_seen
#define neo_AbstractFramework_hh_seen
namespace neo {
namespace cca {


/** 
 * Memory lifecycle:
 *
 * If this interface is received through a function argument,
 * createEmptyFramework/destroyEmptyFramework must be
 * used as noted. The usual rule applies: only the
 * code creating the AbstractFramework instance should
 * destroy it.
 */
class AbstractFramework 
{

public:
  
  virtual ~AbstractFramework(){}

  virtual TypeMap_shared createTypeMap()= 0;

  virtual Services *getServices(const std::string & selfInstanceName, const std::string & selfClassName, TypeMap_shared selfProperties)= 0;

  virtual void releaseServices( Services * svc)= 0;

  /** Tell the framework to close up shop, but the framework
   * instance still needs to be deallocated by falling off the stack
   * or by being deleted or by being passed back to
   * destroyEmptyFramework() in the case that it was
   * created with createEmptyFramework.
   */
  virtual void shutdownFramework()= 0;

  /** Constructor of a sub-framework instance -- a separate
   * container from this one with the same implementation,
   * but probably little or no common content.
   */
  virtual AbstractFramework * createEmptyFramework()= 0;

  /** Destructor of a framework instance obtained from
   *  createEmptyFramework. 
   *  subframe->shutdown() will be called if it has not
   *  already been.
   */
  virtual void destroyEmptyFramework( AbstractFramework * subframe)= 0;

};

}  // end namespace cca
}  // end namespace neo

#endif // neo_AbstractFramework_hh_seen
