#ifndef __neo_Component_hh_seen
#define __neo_Component_hh_seen

namespace neo {
namespace cca {

/** Component object model that all Components wishing to use the
 * boost/STL-based memory model must use.
 */
class Component 
{
public:
  
  /** obligatory virtual destructor */
  virtual ~Component(){}

  /** The component's containing framework provides services through
      the Services interface.

      The Component instance will be called first with 
      some non-0  (non-null) Services object. In order to
      do anything substantial as a component, the component
      will need to keep a copy of this pointer.

      If the cc passed on the first call to setServices
      is 0/null, the component is free to ignore it or
      to throw an exception.

      The next time that setServices is called, the
      argument cc will be 0/null, and that is the
      signal that the component should shut itself down.
      Shutdown is:
        releasing used ports.
	unregistering uses ports.
	removing provided ports.
	deallocating any other resources that
	are not released by the destructor function.

      A second call to setServices with a non-0 cc
      that is made before a shutdown call (0 cc) is received
      is a framework error. The component is free to ignore it
      or to throw an exception.
   */
  virtual void setServices(Services *cc) throw(Exception )= 0;

};

}  // end namespace cca
}  // end namespace neo

#endif // __neo_Component_hh_seen
