#ifndef neo_Type_h_seen
#define neo_Type_h_seen

/* A file of auxiliaries that mainly distract the new reader.  */

namespace neo {
namespace cca {


/** Mapping of sidl/java primitive types and arrays to
 occuring in the TypeMap interface to integers. 
 The values in this enum must not overlap names with ExceptionType.
 */
enum Type {
  /** Undefined primitive type.
      This Includes things like
      long double, short, unsigned, char, etc that are C-isms
      unknown in java.
   */
  NoType = -1,

  /** A signed, 32 bit int. */
  Int = 1,

  /** A signed, 64 bit int. */
  Long = 2,

  /** A 32 bit floating point number. */
  Float = 3,

  /** A 64 bit floating point number. */
  Double = 4,

  /** A 32x2 bit complex float number, a_f + b_f*i. */
  Fcomplex = 5,

  /** A 64x2 bit complex float number, a_d + b_d*i. */
  Dcomplex = 6,

  /** A string, in the language native representation. */
  String = 7,

  /** A boolean value in the language native representation. */
  Bool = 8,

  /** An array of Int */
  IntArray = 21,

  /** An array of Long */
  LongArray = 22,

  /** An array of Float */
  FloatArray = 23,

  /** An array of Double */
  DoubleArray = 24,

  /** An array of Fcomplex */
  FcomplexArray = 25,

  /** An array of Dcomplex */
  DcomplexArray = 26,

  /** An array of String  */
  StringArray = 27,

  /** An array of Bool */
  BoolArray = 28,

} ; // end enum Type


}  // end namespace cca
}  // end namespace neo

#endif // neo_Type_h_seen
