#ifndef neo_BasicParameterPort
#define neo_BasicParameterPort

namespace neo {
namespace cca {
namespace ports {

/**
 * simple version just exposing the typemap.
 * The only values in the typemap a component thus
 * exposes that can be changed are those returned from
 * readConfigurationKeys.
 */
class BasicParameterPort : public virtual neo::cca::Port
{
public:
	
	virtual ~BasicParameterPort() {}

	/** return the names of available parameter maps. */
	virtual std::vector< std::string > readConfigurationKeys()= 0;

	/** return a *copy* of the named map, for the caller to modify. */
	virtual neo::cca::TypeMap_shared readConfigurationMap() throw ( neo::cca::Exception )= 0;

	/** Take values from the modifed map, tm, and copy them to the
	 * internal map of the given name. Implementers are free to ignore
	 * irrelevant data given in tm. I.e. only the values from tm
	 * with keys matching those in readConfigurationKeys will be taken.
	 */
	virtual void writeConfigurationMap( neo::cca::TypeMap_shared tm) throw ( neo::cca::Exception )= 0;

}; // end interface BasicParameterPort


}  // end namespace ports
}  // end namespace cca
}  // end namespace neo
#endif // neo_BasicParameterPort
