#ifndef __neoConnectionEventListener_H__
#define __neoConnectionEventListener_H__

namespace neo {
namespace cca {
namespace ports {

/** A component wishing to be notified of connections
 * on itself can inherit and implement this
 * interface or delegate its implementation as
 * desired. Because of this, it is strictly an
 * interface with a well defined lifecycle
 * in ConnectionEventService and not wrapped
 * in a shared_ptr.
 */
class ConnectionEventListener {
public:
	
  /** obligatory vdtor */
  virtual ~ConnectionEventListener() {}

  /** Connection event hook a component may supply.
      Any action by the component on its Services is
      allowed during the connection activity, including
      getting, using, releasing, and unregistering a uses port. */
  virtual void connectionActivity(ConnectionEvent_shared evt)= 0;
};


}  // end namespace ports
}  // end namespace cca
}  // end namespace neo

#endif // __neoConnectionEventListener_H__
