#ifndef neo_ports_Loader_hh_seen
#define neo_ports_Loader_hh_seen
namespace neo {
namespace cca {
namespace ports {


//===================================================================
//===================================================================

/** NOT YET DEFINED IN CCA.SIDL:
 * This is related to, but not the same as, cca ComponentRepository
 * or ComponentFactory or sidl.DLL or sidl.Loader.
 * It gives access to the global resources that handle dynamic
 * loading of components (.so, .dll).
 */ 
class Loader : public virtual neo::cca::Port
{
public:
	
  virtual ~Loader() {}


  /** replace current path with new paths. each vector element is one
   * directory name. Path is searched for .cca and possibly .scl elements.
   */
  virtual void setPath(const std::vector< std::string > & paths)= 0;

  /** return the list of directories searched for .cca files. */
  virtual std::vector< std::string > getPath()= 0;

  /**
   * Cause the named port interface library to be dynamically loaded.
   * The port class will be loaded globally, as interfaces
   * between components must be globally defined.
   * @return 0 if loaded, nonzero if some problem detected.
   */
  virtual int loadPortLibrary( const std::string & portLibraryName)= 0;

  /**
   * Cause the named class to become instantiable by a subsequent
   * call to BuilderSErvice.createComponentInstance(). This activity
   * may require side effects with dlopen.
   *   In dlopen terms, lazy=true -> RTLD_LAZY, false->RTLD_NOW;
   *                  global=true ->RTLD_GLOBAL, false->RTLD_LOCAL.
   */
  virtual void loadComponent( const std::string & paletteClassAlias , bool global, bool lazy)= 0;

}; // end class Loader


}  // end namespace ports
}  // end namespace cca
}  // end namespace neo

#endif // neo_ports_Loader_hh_seen
