#ifndef neoMPIBorrow_h_seen
#define neoMPIBorrow_h_seen

//requires:
//#include <neocca.h>
//#include <mpi.h>
#ifdef MPI_COMM_NULL // this file is empty if mpi.h is not included

namespace neo {
namespace cca {
namespace ports {


/** "neo.cca.ports.MPIBorrow" :UNADOPTED-standard service
 * for getting a shared communicator. 
 */

class MPIBorrow : public virtual neo::cca::Port {

public:
	

  /** obligatory vdtor */
  virtual ~MPIBorrow() {}

  /** Get a communicator of the port provider.
   This communicator will be the same instance as the comm of the
   port provider, with all the message collision potential that implies.
   Instances which have a comm covering only a subset of themselves
   may return MPI_COMM_NULL on their "un-covered" processes.
   @param tagCount Input: The number of tags the borrower wishes to use
                 all to itself.
   @param tagList Output: Array to be filled with tags available. The
	                        array given is tagCount long.
   @param key Output: key to be returned when the tags and comm are done
	                    with.
   @return The comm being borrowed.
  */
  virtual MPI_Comm borrowComm(int tagCount, int *tagList, int &key)= 0;

  /** Return a previously borrowed communicator and tag list.
   *  @param tagCount Input: The length of tagList.
   *  @param tagList Input: The tags being returned, tagCount long.
   *  @param key Input: The key obtained with borrowComm. It is
   *         an error to attempt to return tags that you didn't receive.
   *  @return -1 if an error is detected, 0 otherwise.
   */
  virtual void returnComm(MPI_Comm, int tagCount, int *tagList, int key)= 0;
};

}  // end namespace ports
}  // end namespace cca
}  // end namespace neo

#endif // MPI_CONGRUENT

#endif // neoMPIBorrow_h_seen
