#ifndef neo_ParameterPort
#define neo_ParameterPort

namespace neo {
namespace cca {
namespace ports {


/** interface for querying adjustable parameters,
 * their ranges, help strings, groupings for UI
 * purposes, etc.
 */
class ParameterPort : public virtual BasicParameterPort
{
public:
	
	virtual ~ParameterPort() {}

	// BasicParameterPort
	
	/** return the names of available parameter maps. */
	virtual std::vector< std::string > readConfigurationKeys()= 0;

	/** return a *copy* of the named map, for the caller to modify. */
	virtual neo::cca::TypeMap_shared readConfigurationMap() throw ( neo::cca::Exception )= 0;

	/** take values from the modifed map, tm, and copy them to the
	 * internal map of the given name. Implementers are free to ignore
	 * irrelevant data given in tm.
	 */
	virtual void writeConfigurationMap( neo::cca::TypeMap_shared tm) throw ( neo::cca::Exception )= 0;

	virtual std::string readTitle()= 0;
	virtual std::vector< std::string > readGroupNames()= 0;
	virtual std::string readGroupTitle( const std::string & groupName)= 0;
	virtual std::vector< std::string > readGroupKeys( const std::string & groupName )= 0;

	virtual std::string readHelp( const std::string & key)= 0;
	virtual std::string readPrompt( const std::string & key)= 0;
	virtual bool hasBounds( const std::string & key)= 0;
	virtual bool hasChoices( const std::string & key)= 0;

	virtual bool readDefaultBoolean( const std::string & key)= 0;
	virtual std::string readDefaultString ( const std::string & key)= 0;
	virtual int32_t readDefaultInt( const std::string & key)= 0;
	virtual int64_t readDefaultLong( const std::string & key)= 0;
	virtual float readDefaultFloat ( const std::string & key)= 0;
	virtual double readDefaultDouble( const std::string & key)= 0;
	virtual std::complex<float> readDefaultFcomplex( const std::string & key)= 0;
	virtual std::complex<double> readDefaultDcomplex( const std::string & key)= 0;

	virtual std::vector< std::string > readDefaultStringArray( const std::string & key)= 0;
	virtual std::vector< bool > readDefaultBooleanArray( const std::string & key)= 0;
	virtual std::vector< int32_t > readDefaultIntArray( const std::string & key)= 0;
	virtual std::vector< int64_t > readDefaultLongArray( const std::string & key)= 0;
	virtual std::vector< float > readDefaultFloatArray( const std::string & key)= 0;
	virtual std::vector< double > readDefaultDoubleArray( const std::string & key)= 0;
	virtual std::vector< std::complex<float> > readDefaultFcomplexArray( const std::string & key)= 0;
	virtual std::vector< std::complex<double> > readDefaultDcomplexArray( const std::string & key)= 0;
	
	virtual void readBoundsInt(const std::string & key, int32_t & low, int32_t & high)= 0;
	virtual void readBoundsLong(const std::string & key, int64_t & low, int64_t & high)= 0;
	virtual void readBoundsFloat(const std::string & key, float & low, float & high)= 0;
	virtual void readBoundsDouble(const std::string & key, double & low, double & high)= 0;

	virtual std::vector< std::string > readChoicesString(const std::string & key)= 0;
	virtual std::vector< int32_t > readChoicesInt(const std::string & key)= 0;
	virtual std::vector< int64_t > readChoicesLong(const std::string & key)= 0;
	virtual std::vector< float > readChoicesFloat(const std::string & key)= 0;
	virtual std::vector< double > readChoicesDouble(const std::string & key)= 0;
	virtual std::vector< std::complex<float> > readChoicesFcomplex(const std::string & key)= 0;
	virtual std::vector< std::complex<double> > readChoicesDcomplex(const std::string & key)= 0;

}; // end interface ParameterPort


}  // end namespace ports
}  // end namespace cca
}  // end namespace neo
#endif // neo_ParameterPort
